pyxmpp.jabber.muccore.MucOwnerX

Package pyxmpp :: Package jabber :: Module muccore :: Class MucOwnerX |
[hide private]

# Class MucOwnerX

source code

                            object --+
                                     |
    objects.StanzaPayloadWrapperObject --+
                                         |
                                  MucXBase --+
                                             |
                                            MucOwnerX

Wrapper for http://www.jabber.org/protocol/muc#owner namespaced stanza payload "x" elements and usually containing information about a room user.

Instance Methods | [hide private]
Inherited from `MucXBase`: `__del__`, `__init__`, `free`, `free_borrowed`, `serialize`, `xpath_eval` Inherited from `objects.StanzaPayloadWrapperObject`: `as_xml` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `MucXBase`: `element`, `ns`

Instance Variables | [hide private]
`libxml2.xmlNode` | xmlnode XML node of the object.

Properties | [hide private]
Inherited from `object`: `__class__`